summaryrefslogtreecommitdiff
path: root/CORE/VOSS/src
diff options
context:
space:
mode:
authorYingying Tang <yintang@qti.qualcomm.com>2016-06-02 17:55:10 +0800
committerAnjaneedevi Kapparapu <akappa@codeaurora.org>2016-06-29 18:12:11 +0530
commitd1ce9c70ab751f0b7d8ecc267858fee94a2816d2 (patch)
tree5cc57648031895071421a286a6676b0602aa3d13 /CORE/VOSS/src
parent51e5dc37b48c43c35dc945535a03bd16a8012854 (diff)
qcacld-2.0: Set number of clients separately for SAP and GO
Currently there is only one ini item gSoftApMaxPeers to configure max SAP clients number, and this item will also affect GO clients. Add another ini item to set GO clients number. Change-Id: I9aaacf035efb042f8216ca0d7f1ec3f21f11b212 CRs-Fixed: 1023547
Diffstat (limited to 'CORE/VOSS/src')
-rw-r--r--CORE/VOSS/src/vos_api.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/CORE/VOSS/src/vos_api.c b/CORE/VOSS/src/vos_api.c
index b80c021b9499..dc96f4f4d7b6 100644
--- a/CORE/VOSS/src/vos_api.c
+++ b/CORE/VOSS/src/vos_api.c
@@ -496,7 +496,7 @@ VOS_STATUS vos_open( v_CONTEXT_t *pVosContext, v_SIZE_t hddContextSize )
scn->enableuartprint = pHddCtx->cfg_ini->enablefwprint;
scn->enablefwlog = pHddCtx->cfg_ini->enablefwlog;
scn->enableFwSelfRecovery = pHddCtx->cfg_ini->enableFwSelfRecovery;
- scn->max_no_of_peers = pHddCtx->cfg_ini->maxNumberOfPeers;
+ scn->max_no_of_peers = pHddCtx->max_peers;
#ifdef WLAN_FEATURE_LPSS
scn->enablelpasssupport = pHddCtx->cfg_ini->enablelpasssupport;
#endif
@@ -661,9 +661,9 @@ VOS_STATUS vos_open( v_CONTEXT_t *pVosContext, v_SIZE_t hddContextSize )
/* Number of peers limit differs in each chip version. If peer max
* limit configured in ini exceeds more than supported, WMA adjusts
* and keeps correct limit in macOpenParms.maxStation. So, make sure
* ini entry pHddCtx->cfg_ini->maxNumberOfPeers has adjusted value
*/
- pHddCtx->cfg_ini->maxNumberOfPeers = macOpenParms.maxStation;
+ pHddCtx->max_peers = macOpenParms.maxStation;
HTCHandle = vos_get_context(VOS_MODULE_ID_HTC, gpVosContext);
if (!HTCHandle) {
VOS_TRACE(VOS_MODULE_ID_VOSS, VOS_TRACE_LEVEL_FATAL,
@@ -661,9 +661,9 @@ VOS_STATUS vos_open( v_CONTEXT_t *pVosContext, v_SIZE_t hddContextSize )
* limit configured in ini exceeds more than supported, WMA adjusts
* and keeps correct limit in macOpenParms.maxStation. So, make sure
- * ini entry pHddCtx->cfg_ini->maxNumberOfPeers has adjusted value
+ * pHddCtx->max_peers has adjusted value
*/